pub struct AdminDatabaseConfiguration {
pub host: String,
pub port: u16,
pub setup_user: Option<AdminDatabaseSetupUserConfig>,
pub setup_user_secret_name: Option<String>,
pub root_secret_name: Option<String>,
pub root_iam: bool,
}Expand description
Administrative database credentials configuration used for managing the database
Fields
host: StringHost of the database
port: u16Port of the database
setup_user: Option<AdminDatabaseSetupUserConfig>Setup user configuration if using an inline one
setup_user_secret_name: Option<String>Name of the setup user secret if using one
root_secret_name: Option<String>Name of the secrets manager secret to use when connecting to the root “docbox” database if using secret based authentication
root_iam: boolWhether to use IAM authentication instead of secret based authentication for connecting to the root database