Module database

Module database 

Modules

create
docbox-database re-exports
migrations
docbox-database re-exports
models
docbox-database re-exports
pool
docbox-database re-exports
sqlx
docbox-database re-exports The async SQL toolkit for Rust, built with ❤️ by the LaunchBadge team.
utils
docbox-database re-exports

Structs

CloseOnDrop
DatabasePoolCache
docbox-database re-exports Cache for database pools
DatabasePoolCacheConfig
docbox-database re-exports Config for the database pool
DbSecrets
docbox-database re-exports Username and password for a specific database
PgConnectOptions
docbox-database re-exports Options and flags which can be used to configure a PostgreSQL connection.
Postgres
docbox-database re-exports PostgreSQL database driver.
Transaction
docbox-database re-exports An in-progress database transaction or savepoint.

Enums

DatabasePoolCacheConfigError
docbox-database re-exports
DbConnectErr
docbox-database re-exports

Constants

ROOT_DATABASE_NAME
docbox-database re-exports Name of the root database

Traits

DatabaseProvider
Provider to get database access for the management tool
DbExecutor
docbox-database re-exports An alias for Executor<'_, Database = Postgres>.

Functions

close_pool_on_drop

Type Aliases

DbErr
docbox-database re-exports Short type alias for a database error
DbPool
docbox-database re-exports Type of the database connection pool
DbResult
docbox-database re-exports Type alias for a result where the error is a DbErr
DbTransaction
docbox-database re-exports Type of a database transaction
PgPool
docbox-database re-exports An alias for Pool, specialized for Postgres.
PgPoolOptions
docbox-database re-exports An alias for PoolOptions, specialized for Postgres.