DatabaseProvider

Trait DatabaseProvider 

pub trait DatabaseProvider:
    Send
    + Sync
    + 'static {
    // Required method
    fn connect(
        &self,
        database: &str,
    ) -> impl Future<Output = DbResult<DbPool>> + Send;
}
Provider to get database access for the management tool

Expects that the access granted to the database is sufficient for creation and deletion of tables

Required Methods

fn connect( &self, database: &str, ) -> impl Future<Output = DbResult<DbPool>> + Send

Connect to the provided database providing back a DbPool

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors