pub struct ManagedServerInterface {
pub server: ManagedServer,
pub config: ServerConfigData,
}Fields
server: ManagedServerconfig: ServerConfigDataTrait Implementations
Sourceimpl DocboxManagementInterface for ManagedServerInterface
impl DocboxManagementInterface for ManagedServerInterface
Sourcefn check_root<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<CheckRootOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn check_root<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<CheckRootOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Checks if the docbox root database has been initialized
Sourcefn create_root<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create_root<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Create the root docbox database
Sourcefn create_tenant<'life0, 'async_trait>(
&'life0 self,
input: CreateTenantInput,
) -> Pin<Box<dyn Future<Output = Result<CreateTenantOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create_tenant<'life0, 'async_trait>(
&'life0 self,
input: CreateTenantInput,
) -> Pin<Box<dyn Future<Output = Result<CreateTenantOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Create a new tenant
Sourcefn get_tenant<'life0, 'async_trait>(
&'life0 self,
input: GetTenantInput,
) -> Pin<Box<dyn Future<Output = Result<GetTenantOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_tenant<'life0, 'async_trait>(
&'life0 self,
input: GetTenantInput,
) -> Pin<Box<dyn Future<Output = Result<GetTenantOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Get a specific tenant
Sourcefn delete_tenant<'life0, 'async_trait>(
&'life0 self,
input: DeleteTenantInput,
) -> Pin<Box<dyn Future<Output = Result<DeleteTenantOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_tenant<'life0, 'async_trait>(
&'life0 self,
input: DeleteTenantInput,
) -> Pin<Box<dyn Future<Output = Result<DeleteTenantOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Delete a specific tenant
Sourcefn get_tenants<'life0, 'async_trait>(
&'life0 self,
input: GetTenantsInput,
) -> Pin<Box<dyn Future<Output = Result<GetTenantsOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_tenants<'life0, 'async_trait>(
&'life0 self,
input: GetTenantsInput,
) -> Pin<Box<dyn Future<Output = Result<GetTenantsOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Get a collection of tenants
Sourcefn set_tenant_allowed_cors_origins<'life0, 'async_trait>(
&'life0 self,
input: SetTenantAllowedCorsOriginsInput,
) -> Pin<Box<dyn Future<Output = Result<(), ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn set_tenant_allowed_cors_origins<'life0, 'async_trait>(
&'life0 self,
input: SetTenantAllowedCorsOriginsInput,
) -> Pin<Box<dyn Future<Output = Result<(), ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Set the allowed CORS origins for a tenants storage bucket
Sourcefn migrate_root<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn migrate_root<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Apply root database migrations
Sourcefn migrate_tenant<'life0, 'async_trait>(
&'life0 self,
input: MigrateTenantInput,
) -> Pin<Box<dyn Future<Output = Result<MigrateTenantOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn migrate_tenant<'life0, 'async_trait>(
&'life0 self,
input: MigrateTenantInput,
) -> Pin<Box<dyn Future<Output = Result<MigrateTenantOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Apply migrations for tenant(s)
Sourcefn migrate_tenant_iam<'life0, 'async_trait>(
&'life0 self,
input: MigrateTenantIAMInput,
) -> Pin<Box<dyn Future<Output = Result<MigrateTenantIAMOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn migrate_tenant_iam<'life0, 'async_trait>(
&'life0 self,
input: MigrateTenantIAMInput,
) -> Pin<Box<dyn Future<Output = Result<MigrateTenantIAMOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Migrate a tenant from secrets based authentication to IAM based
database authentication
Sourcefn get_pending_root_migrations<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<String>, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_pending_root_migrations<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<String>, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Get migrations that are waiting to be applied to the root
Sourcefn get_tenant_pending_migrations<'life0, 'async_trait>(
&'life0 self,
input: GetTenantPendingMigrationsInput,
) -> Pin<Box<dyn Future<Output = Result<GetTenantPendingMigrationsOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_tenant_pending_migrations<'life0, 'async_trait>(
&'life0 self,
input: GetTenantPendingMigrationsInput,
) -> Pin<Box<dyn Future<Output = Result<GetTenantPendingMigrationsOutput, ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Get pending database migrations for a specific tenant
Sourcefn flush_tenant_cache<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn flush_tenant_cache<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), ManagementError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Flush the tenant database cache for persisted servers