Module initialize

Module initialize 

Enums

InitializeError

Functions

initialize
Initializes the root database of docbox using a secret based authentication
initialize_iam
Initializes the root database of docbox using IAM based authentication
initialize_root_database
Initializes the root database used by docbox
initialize_root_role
Initializes a root role that the docbox API will use when accessing the tenants table
initialize_root_role_aws_iam
Initializes a root IAM accessible role that the docbox API will use when accessing the tenants table
initialize_root_secret
Initializes and stores the secret for the root database access
is_initialized
Check if the root database is initialized