pub struct CreateTenantConfig {
pub id: TenantId,
pub name: String,
pub env: String,
pub db_name: String,
pub db_role_name: String,
pub db_secret_name: Option<String>,
pub db_iam_user: bool,
pub storage_bucket_name: String,
pub storage_cors_origins: Vec<String>,
pub storage_s3_queue_arn: Option<String>,
pub search_index_name: String,
pub event_queue_url: Option<String>,
}Expand description
Request to create a tenant
Fields
id: TenantIdUnique ID for the tenant
name: StringName of the tenant
env: StringEnvironment of the tenant
db_name: StringDatabase name for the tenant
db_role_name: StringName for the tenant role
db_secret_name: Option<String>Database secret credentials name for the tenant (Where the username and password will be stored)
db_iam_user: boolWhether to use IAM for role authorization instead of a database secret
storage_bucket_name: StringName of the tenant storage bucket
storage_cors_origins: Vec<String>CORS Origins for setting up presigned uploads with S3
storage_s3_queue_arn: Option<String>ARN for the S3 queue to publish S3 notifications, required for presigned uploads
search_index_name: StringName of the tenant search index
event_queue_url: Option<String>URL for the SQS event queue