pub trait DatabaseProvider:
Send
+ Sync
+ 'static {
// Required method
fn connect(
&self,
database: &str,
) -> impl Future<Output = DbResult<DbPool>> + Send;
}Expand description
Provider to get database access for the management tool
Expects that the access granted to the database is sufficient for creation and deletion of tables
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.