Enums
Functions
- initialize
- Initializes the root database of docbox using a secret based authentication
- initialize_
iam - Initializes the root database of docbox using IAM based authentication
- initialize_
root_ database - Initializes the root database used by docbox
- initialize_
root_ role - Initializes a root role that the docbox API will use when accessing the tenants table
- initialize_
root_ role_ aws_ iam - Initializes a root IAM accessible role that the docbox API will use when accessing the tenants table
- initialize_
root_ secret - Initializes and stores the secret for the root database access
- is_
initialized - Check if the root database is initialized